<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Yummy Pro
 * @since Yummy Pro 1.0
 * @return array An array of default values
 */

function yummy_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	
	$yummy_pro_default_options = array(

		//slider section
		'enable_slider'                 => true,
		'slider_content_type'           => 'demo',
		'slider_transition'             => 'cubic-bezier(0.250, 0.100, 0.250, 1.000)',
		'enable_infinite_sliding'       => true,
		'slider_speed'                  => 800,
		'enable_slider_pager'           => true,
		'enable_slider_arrows'			=> true,
		'enable_slider_autoplay'        => true,
		'make_slider_draggable'         => false,
		'number_of_slider'              => 3,
		'enable_slider_logo'			=> true,
		'slider_logo_image'     		=> get_template_directory_uri().'/assets/uploads/slider-logo.png',

		//about section
		'enable_about'                  => true,
		'about_content_type'            => 'demo',

		//special item section
		'enable_special_item'           => true,
		'special_item_header_type'      => 'demo',
		
		'special_item_header_image'     => get_template_directory_uri().'/assets/uploads/delicious.jpg',
		'special_item_header_title'     => esc_html__( 'Delicious Recipe', 'yummy-pro' ),
		'special_item_content_type'     => 'demo',
		'special_item_content_count'    => 4,

		// Call to action section
		'enable_call_to_action'			=> true,
		'call_to_action_type'			=> 'demo',
		'call_to_action_title'			=> esc_html__( 'We Cook delicious memory', 'yummy-pro' ),
		'call_to_action_btn_label'		=> esc_html__( 'Buy Now', 'yummy-pro' ),
		'call_to_action_page_btn_label' => esc_html__( 'View', 'yummy-pro' ),
		'call_to_action_image'       	=> get_template_directory_uri() . '/assets/uploads/memory.jpg',

		//testimonial section
		'enable_testimonial'           	=> true,
		'testimonial_header_type'      	=> 'demo',
		'testimonial_header_image'     	=> get_template_directory_uri() . '/assets/uploads/parallax-bg.jpg',
		'testimonial_header_title'     	=> esc_html__( 'They are fond of our food', 'yummy-pro' ),
		'testimonial_content_type'     	=> 'demo',

		// item menu section
		'enable_item_menu'				=> true,
		'item_menu_title'				=> esc_html__( 'Menu', 'yummy-pro' ),
		'item_menu_type'				=> 'demo',

		//recipe section
		'enable_recipe'					=> true,
		'button_label'					=> esc_html__( 'Full Recipe','yummy-pro' ),
		'recipe_content_type'			=> 'demo',

		// special day section
		'enable_special_day'			=> true,
		'special_day_background_image'	=> get_template_directory_uri().'/assets/uploads/rock.jpg',
		'special_day_left_type'			=> 'demo',
		'special_day_left_note'			=> sprintf( esc_html__( '%1$sRock%2$s %3$sFriday%4$s %5$sWe cook special in%6$s %7$sSpecial day%8$s', 'yummy-pro' ), '<h2>', '</h2>', '<span>', '</span>', '<p>', '</p>', '<h3>', '</h3>'  ),
		'special_day_left_btn_title'	=> esc_html__( 'Reservation', 'yummy-pro' ),
		'special_day_right_note_type'	=> 'demo',
		'special_day_right_type'		=> 'demo',
		'special_day_right_count'		=> 5,
		'special_day_right_note_title'	=> esc_html__( 'Hi, Today is Rock Friday', 'yummy-pro' ),
		'special_day_right_note_description' => sprintf( esc_html__( '%1$sPellentesque aliquam felis id justo efficitur, eu commodo sem vestibulum. Morbi vulputate tortor nec est mollis, et dignissim nisi malesuada. Ut et ornare lectus. Accumsan sapien, eget venenatis velit dolor eu est.%2$s %1$sCras at lacus eros. Donec vitae nibh finibus, faucibus felis auctor, varius arcu.%2$s', 'yummy-pro' ), '<p>', '</p>' ),
		
		// Theme Options
		'header_theme_typography' 		=> 'default',
		'body_theme_typography' 		=> 'default',
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'fa-spinner',
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'short_excerpt_length'          => 10,
		'blog_page_title'				=> esc_html__( 'Blogs','yummy-pro' ),
		'hide_author_avatar'			=> false,
		'hide_blog_date'				=> false,
		'read_more_text'		        => esc_html__( 'View Details', 'yummy-pro' ),
		'breadcrumb_enable'         	=> true,
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',
		'scroll_top_visible'        	=> true,
		'reset_options'      			=> false,
		'enable_frontpage_content' 		=> true,
		'disable_primary_menu'			=> false,
		'disable_search'				=> false,
		'disable_add_to_cart'			=> false,
		'theme_color'					=> 'golden',
		'hide_author'					=> false,
		'hide_category'					=> false,
		'hide_tags'						=> false,
		'hide_date'						=> false,
		'hide_single_pagination'		=> false,
		'site_title_enable'				=> true,
		'site_description_enable'		=> true,
		'site_logo_enable'				=> true,
		'enable_header_on_frontpage'	=> false,

		//Footer Editor Options
		'enable_footer'					=> 'static-front-page',
		'footer_background_image'		=> get_template_directory_uri().'/assets/uploads/footer-wrapper.jpg',
		'copyright_text'                => sprintf( _x( 'Copyright &copy; %1$s %2$s. All Rights Reserved', '1: Year, 2: Site Title with home URL', 'yummy-pro' ), '[the-year]', '[site-link]' ),
		'powered_by'                    =>  esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'yummy-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( $theme_data->get( 'Author' ) ) .'</a>',
		'copyright_background_image'	=> get_template_directory_uri().'/assets/uploads/site-info.jpg',
		'scroll_top_visible'            => true,

		//custom contact us template
		'contact_us_title'				=> esc_html__( 'Get In Touch','yummy-pro' ),
		'contact_form_title'			=> esc_html__( 'Contact Info','yummy-pro' ),
		'contact_us_description'		=> esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vestibulum fermentum est eu imperdiet com modo. Phasellus rhoncus dui nec ipsum tempus, eu feugiat ipsum hendrerit. Proin non semper velit, ac dapibus nulla.','yummy-pro' ),
		'location'						=> esc_html__( 'Jawlakhel, Kathmandu, Nepal','yummy-pro' ),
		'contact_email'					=> 'info@themepalace.com',
		'contact_number'				=> '+977-9846120045',
		'contact_form_background_image'	=> get_template_directory_uri().'/assets/uploads/contact-form-bg.png',
		'enable_contact_form'			=> true,
		'enable_map'					=> true,

		//custom about -us
		'gallery_button_text'			=> esc_html__( 'View Gallery','yummy-pro' ),
		'about_us_content_type'			=> 'post',
		'number_of_about_slider'		=> 3,
		'about_us_team_content_type'	=> 'post',
		'about_us_advert_content_type'	=> 'page',
		'about_us_choice_content_type'	=> 'category',
		'about_us_interior_content_type'=> 'page',
		'interior_decoration_title'		=> esc_html__( 'Interior Decoration','yummy-pro' ),
		'interior_decoration_subtitle'	=> esc_html__( 'Enjoy Your Stay','yummy-pro' ),
		'interior_category_title'		=> esc_html__( 'Bar','yummy-pro' ),
		'interior_custom_title'			=> esc_html__( 'Drink Red Wine','yummy-pro' ),

		// shop page
		'sale_title'					=> esc_html__( 'Holiday', 'yummy-pro' ),
		'sale_sub_title'				=> esc_html__( 'Special Offer', 'yummy-pro' ),
		'shop_pagination_type'			=> 'numeric',

		//reservation
		'reservation_content_type'		=> 'page',
		'reservation_header_type'		=> 'page',
		'reservation_header_image'		=> get_template_directory_uri().'/assets/uploads/memorable.jpg',
		'memorable_reservation_type'	=> 'post',
		'reservation_header_title'		=> esc_html__( 'A truly memorable one','yummy-pro' ),
		'online_reservation_title'		=> esc_html__( 'Make Online Reservation','yummy-pro' ),
		'online_reservation_description'=> esc_html__( 'We take reservations for lunch and dinner but we do not book the bar area we leave this for walk-in guests to ensure that we always offer some tables for those who have not booked.','yummy-pro' ),

		// menu page
		'menu_first_section_title'		=> esc_html__( 'Menu Of The Day', 'yummy-pro' ),
		'menu_first_section_content_type'	=> 'category',
		'menu_second_section_title'		=> esc_html__( 'Breakfast', 'yummy-pro' ),
		'menu_second_section_image'		=> get_template_directory_uri().'/assets/uploads/breakfast.jpg',
		'menu_second_section_content_type'	=> 'category',
		'menu_third_section_title'		=> esc_html__( 'Lunch', 'yummy-pro' ),
		'menu_third_section_sub_title'	=> esc_html__( 'All about good taste', 'yummy-pro' ),
		'menu_third_section_image'		=> get_template_directory_uri().'/assets/uploads/lunch.jpg',
		'menu_third_section_content_type'	=> 'category',
		'menu_forth_section_title'		=> esc_html__( 'Dinner', 'yummy-pro' ),
		'menu_forth_section_image'		=> get_template_directory_uri().'/assets/uploads/dinner.jpg',
		'menu_forth_section_content_type'	=> 'category',
		'menu_fifth_section_title'		=> esc_html__( 'Drinks', 'yummy-pro' ),
		'fifth_section_title'			=> esc_html__( 'Drinks', 'yummy-pro' ),
		'fifth_section_subtitle'		=> esc_html__( 'From Coffee To Wine', 'yummy-pro' ),
		'menu_fifth_section_image'		=> get_template_directory_uri().'/assets/uploads/drinks.jpg',
		'menu_fifth_section_content_type'	=> 'category',

	);

	$output = apply_filters( 'yummy_pro_default_theme_options', $yummy_pro_default_options );
	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}