<?php
/**
 * Call to action options
 *
 * @package Theme Palace
 * @subpackage Yummy pro
 * @since Yummy Pro 1.0
 */

// Add Call to action section
$wp_customize->add_section( 'yummy_pro_call_to_action_section', array(
	'title'             => esc_html__( 'Call To Action Section','yummy-pro' ),
	'description'       => esc_html__( 'Call To Action options.', 'yummy-pro' ),
	'panel'             => 'yummy_pro_sections_panel',
) );

/**
 * Call To Action Options
 */
// Enable Call To Action.
$wp_customize->add_setting( 'yummy_pro_theme_options[enable_call_to_action]', array(
	'default'           => $options['enable_call_to_action'],
	'sanitize_callback' => 'yummy_pro_sanitize_checkbox',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[enable_call_to_action]', array(
	'label'             => esc_html__( 'Enable Call To Action Section', 'yummy-pro' ),
	'section'           => 'yummy_pro_call_to_action_section',
	'type'				=> 'checkbox'
) );

/**
 * Call To Action Header type options.
 *
 * Choices options are similar to special item header section therefore choices function is reused. 
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[call_to_action_type]', array(
	'default'           => $options['call_to_action_type'],
	'sanitize_callback' => 'yummy_pro_sanitize_select',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[call_to_action_type]', array(
	'active_callback'	=> 'yummy_pro_is_call_to_action_active',
	'label'             => esc_html__( 'Content Type', 'yummy-pro' ),
	'section'           => 'yummy_pro_call_to_action_section',
	'choices'			=> yummy_pro_special_item_header_type_options(),
	'type'				=> 'select'
) );

/**
 * Title Options
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[call_to_action_title]', array(
	'default'           => $options['call_to_action_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[call_to_action_title]', array(
	'active_callback'	=> 'yummy_pro_call_to_action_custom',
	'label'             => esc_html__( 'Title', 'yummy-pro' ),
	'section'           => 'yummy_pro_call_to_action_section',
	'type'				=> 'text'
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'yummy_pro_theme_options[call_to_action_title]', array(
		'selector'            => '#parallax-2 .wrapper .entry-header h2.entry-title a',
		'settings'            => 'yummy_pro_theme_options[call_to_action_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'yummy_pro_call_to_action_title',
    ) );
}

/**
 * Button label Options
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[call_to_action_btn_label]', array(
	'default'           => $options['call_to_action_btn_label'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[call_to_action_btn_label]', array(
	'active_callback'	=> 'yummy_pro_call_to_action_custom',
	'label'             => esc_html__( 'Button Label', 'yummy-pro' ),
	'section'           => 'yummy_pro_call_to_action_section',
	'type'				=> 'text'
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'yummy_pro_theme_options[call_to_action_btn_label]', array(
		'selector'            => '#parallax-2 .wrapper .entry-header a.btn',
		'settings'            => 'yummy_pro_theme_options[call_to_action_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'yummy_pro_call_to_action_btn_label',
    ) );
}

/**
 * Button link Options
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[call_to_action_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[call_to_action_link]', array(
	'active_callback'	=> 'yummy_pro_call_to_action_custom',
	'label'             => esc_html__( 'Button Link', 'yummy-pro' ),
	'section'           => 'yummy_pro_call_to_action_section',
	'type'				=> 'url'
) );

/**
 * Call To Action image setting and control
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[call_to_action_image]', array(
	'default'           => $options['call_to_action_image'],
	'sanitize_callback' => 'yummy_pro_sanitize_image'
) );

$wp_customize->add_control(
	new WP_Customize_Image_Control( $wp_customize, 'yummy_pro_theme_options[call_to_action_image]',
		array(
		'label'       		=> esc_html__( 'Select Image', 'yummy-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'yummy-pro' ), 1500, 1000 ),
		'section'     		=> 'yummy_pro_call_to_action_section',
		'active_callback'	=> 'yummy_pro_call_to_action_custom',
) ) );

/**
 * Call To Action type page Options
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[call_to_action_page]', array(
	'sanitize_callback' => 'yummy_pro_sanitize_page',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[call_to_action_page]', array(
	'active_callback'	=> 'yummy_pro_call_to_action_page',
	'label'             => esc_html__( 'Select Page', 'yummy-pro' ),
	'description'       => esc_html__( 'Info: Make sure selected page has featured image.', 'yummy-pro' ),
	'section'           => 'yummy_pro_call_to_action_section',
	'type'				=> 'dropdown-pages'
) );

/**
 * Page Button label Options
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[call_to_action_page_btn_label]', array(
	'default'           => $options['call_to_action_page_btn_label'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[call_to_action_page_btn_label]', array(
	'active_callback'	=> 'yummy_pro_call_to_action_page',
	'label'             => esc_html__( 'Page Link Button Label', 'yummy-pro' ),
	'section'           => 'yummy_pro_call_to_action_section',
	'type'				=> 'text'
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'yummy_pro_theme_options[call_to_action_page_btn_label]', array(
		'selector'            => '#parallax-2 .wrapper .entry-header a.btn',
		'settings'            => 'yummy_pro_theme_options[call_to_action_page_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'yummy_pro_call_to_action_page_btn_label',
    ) );
}