<?php
/**
 * Template part for displaying posts.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Theme Palace
 * @subpackage Yummy Pro
 * @since Yummy Pro 1.0
 */
if( ! class_exists( 'TP_Recipe' ) ) {
    return;
}
$addcolumn = ( has_post_thumbnail() ) ? 2 : 1;
?>
<section id="recipe" class="col-<?php echo $addcolumn; ?>">
    <div class="wrapper">
        <?php if( has_post_thumbnail() ) { ?>
          	<div class="column-wrapper">
              	<a href="<?php the_permalink(); ?>"><?php the_post_thumbnail( 'full', array( 'alt' => the_title_attribute( 'echo=0' ) ) ); ?></a>
          	</div><!--.column-wrapper-->
        <?php } ?>

      	<div class="column-wrapper">
        	<div class="recipe-sandwich">
          		<header class="entry-header">
            		<img src="<?php echo get_template_directory_uri() . '/assets/uploads/logo-02.png'; ?>" alt="<?php esc_attr_e( 'logo','yummy-pro' ); ?>">
            		<h2 class="entry-title"><?php the_title(); ?></h2>
          		</header><!--.entry-header-->

          		<div class="entry-content">
            	<p><?php the_content(); ?></p>
          		</div><!--.entry-content-->
        	</div><!--.recipe-sandwich-->
      	</div><!--.column-wrapper-->
    </div><!--.wrapper-->

    <div class="page-decoration">
      	<img src="<?php echo get_template_directory_uri().'/assets/uploads/dish-01.png'; ?>" alt="<?php esc_attr_e( 'Decoration','yummy-pro' ); ?>">
        <img src="<?php echo get_template_directory_uri().'/assets/uploads/dish-02.png'; ?>" alt="<?php esc_attr_e( 'Decoration','yummy-pro' ); ?>">
    </div><!-- .page-decoration -->
</section><!-- #recipe -->

<section id="preparation-time" class="col-3">
	<div class="wrapper">
	  	<div class="total-duration add-shadow">
		    <div class="inner-wrap clear">
		        <div class="duration preparation-time">
		            <span><?php esc_html_e( 'Prep','yummy-pro' ); ?></span>
		            <?php 
                    if ( has_action( 'tp_recipe_prep_time_action' ) ) { 
                        /*
                         * @hooked tp_recipe_prep_time
                        */
                        do_action( 'tp_recipe_prep_time_action' ); 
                    } ?>
		            <small><?php esc_html_e( 'mins','yummy-pro' ); ?></small>
		        </div><!-- .preparation-time -->
		        <div class="duration cooking-time">
		            <span><?php esc_html_e( 'Cook','yummy-pro' ); ?></span>
		            <?php 
                    if ( has_action( 'tp_recipe_cook_time_action' ) ) { 
                        /*
                         * @hooked tp_recipe_cook_time
                        */
                        do_action( 'tp_recipe_cook_time_action' ); 
                    } ?>
		            <small><?php esc_html_e( 'mins','yummy-pro' ); ?></small>
		        </div><!-- .cooking-time -->
		        <div class="duration ready-time">
		            <span><?php esc_html_e( 'Ready in','yummy-pro' ); ?></span>
		            <?php 
                    if ( has_action( 'tp_recipe_ready_time_action' ) ) { 
                        /*
                         * @hooked tp_recipe_ready_time
                        */
                        do_action( 'tp_recipe_ready_time_action' ); 
                    } ?>
		            <small><?php esc_html_e( 'mins','yummy-pro' ); ?></small>
		        </div><!-- .preparation-time -->
		    </div><!-- .inner-wrap -->
		</div><!--.duration-->
	</div><!--.wrapper-->
</section><!-- .prepation-time -->


<section id="ingredients">
    <div class="wrapper">
      	<div class="ingredient-wrapper">
        	<img class="ingredient-decoration-1" src="<?php echo get_template_directory_uri().'/assets/uploads/ingredient-decoration-01.png'; ?>" alt="<?php esc_attr_e( 'Ingredient-decoration','yummy-pro'); ?>">
        	<img class="ingredient-decoration-2" src="<?php echo get_template_directory_uri().'/assets/uploads/ingredient-decoration-02.jpg'; ?>" alt="<?php esc_attr_e( 'Ingredient-decoration','yummy-pro'); ?>">
	        <header class="entry-header">
	          	<h2 class="entry-title"><?php esc_html_e( 'Ingredients','yummy-pro' ); ?></h2>
	          	<p class="title-desc"><span><?php esc_html_e( 'For ','yummy-pro' ); ?></span><?php the_title(); ?></p>
	        </header><!--.entry-header-->

	        <div class="entry-content" data-slick='{"slidesToShow": 4, "slidesToScroll": 1, "infinite": true, "speed": 600, "dots": false, "arrows":true, "autoplay": true, "fade": false, "dragable":false}'>
	          	<?php 
                if ( has_action( 'tp_recipe_ingredients_action' ) ) {
                    /*
                     * @hooked tp_recipe_ingredients
                    */
                    do_action( 'tp_recipe_ingredients_action' ); 
                } ?>
        	</div><!--.entry-content-->
      	</div><!--.ingredient-wrapper-->
      	<div class="icon">
        	<?php 
            if ( has_action( 'tp_recipe_upload_link_action' ) ) {
                /*
                 * @hooked tp_recipe_upload_link
                */
                do_action( 'tp_recipe_upload_link_action' );
            }
            if ( has_action( 'tp_recipe_shop_link_action' ) ) {
                /*
                 * @hooked tp_recipe_shop_link
                */             
            	do_action( 'tp_recipe_shop_link_action' ); 
            } ?>
      	</div><!--.icon-->
    </div><!-- .wrapper -->
</section><!-- #ingredients -->

<?php 

if( ! function_exists( 'yummy_pro_get_recipe_related_posts' ) ) :
    /*
     * Function to get recipe related posts.
     */           
    function yummy_pro_get_recipe_related_posts( $post_id = '' ) {
        $tp_recipe_obj = get_the_terms( $post_id, 'tp-recipe-category' );
        if( empty( $tp_recipe_obj ) ) {
            return;
        }
        $term_ids = array();
        foreach ( $tp_recipe_obj as $cat ) {
            $term_ids = array_merge( $term_ids, array( $cat->term_id ) );
        }
        if( empty( $term_ids ) ){
        return;
        }
        $recipe_related_args = array(
            'post_type'      => 'tp-recipe',
            'posts_per_page' => 3,
            'exclude'        => $post_id,                
            'tax_query'      => array(
                array(
                    'taxonomy'  => 'tp-recipe-category',
                    'field'     => 'id',
                    'terms'     => $term_ids,
                )
            ) 
        );

        if( ! empty( $recipe_related_args ) ) {
            $recipe_related_posts = get_posts( $recipe_related_args );
        }

        if( ! empty( $recipe_related_posts ) ) { 
            $index = 1;
            foreach ( $recipe_related_posts as $key => $recipe_related_post ) {
                $page_id = $recipe_related_post->ID;
                $img_array = null;
                if ( has_post_thumbnail( $page_id ) ) {
                    $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $recipe_related_post->ID ), 'post-thumbnail' );
                } 
                else {
                    $img_array[0] =  get_template_directory_uri() . '/assets/uploads/no-featured-image-300x300.jpg';
                }

                if ( isset( $img_array ) ) {
                    $contents[$index]['img_array'] = $img_array;
                }
                $contents[ $index ]['url']         = get_permalink( $page_id );
                $contents[ $index ]['title']       = get_the_title( $page_id );
                $contents[ $index ]['post_id']     = $recipe_related_post->ID;
                $index++;
            } ?> 
            <section id="other-recipe" class="page-section related-recipe">
                <div class="wrapper">
                    <header class="entry-header">
                        <h2 class="entry-title"><?php esc_html_e( 'Related Recipe','yummy-pro' ); ?></h2>
                        <div class="separator"></div>
                    </header><!--.entry-header-->
                    <div class="entry-content">
                        <div class="recipe-content col-3">
                            <div class="row">
                            <?php foreach( $contents as $content ) { ?>
                                <div class="column-wrapper">
                                    <article id="features-post-1">
                                        <figure class="featured-image">  
                                          <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['img_array'][0] ); ?>" alt="<?php esc_attr_e( 'tab','yummy-pro' ); ?>"></a>
                                        </figure>
                                        <div class="entry-container">
                                            <h4><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h4>
                                            <div class="recipe_meta">
                                                <?php 
                                                foreach ( $tp_recipe_obj as $cat ) {
                                                    echo '<span>' . esc_html( $cat->name ) . '</span>';     
                                                } ?>
                                            </div><!--.recipe_meta-->
                                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="more-link fill-black"><?php esc_html_e( 'Full Recipe','yummy-pro' ); ?></a>
                                        </div><!-- .entry-container -->
                                    </article>
                                </div><!--.column-wrapper-->
                            <?php } ?>          
                            </div><!--.row-->
                        </div><!--.recipe-content-->
                    </div><!-- .entry-content-->
                </div><!--.wrapper-->

                <div class="page-decoration">
                    <img src="<?php echo get_template_directory_uri().'/assets/uploads/dish-03.png'; ?>" alt="<?php esc_attr_e( 'Decoration','yummy-pro' ); ?>">
                    <img src="<?php echo get_template_directory_uri().'/assets/uploads/dish-04.png'; ?>" alt="<?php esc_attr_e( 'Decoration','yummy-pro' ); ?>">
                </div><!-- .page-decoration -->
            </section><!--#other-recipe-->
        <?php } 
    }
endif;
add_action( 'yummy_pro_recipe_related_posts', 'yummy_pro_get_recipe_related_posts' );

/*
 * @hooked yummy_pro_get_recipe_related_posts
*/
do_action( 'yummy_pro_recipe_related_posts', get_the_ID() );
